
/* Generated data (by pika-mkenums) */

#include "stamp-config-enums.h"
#include "config.h"
#include <gio/gio.h>
#include "libpikabase/pikabase.h"
#include "config-enums.h"
#include "pika-intl.h"

/* enumerations from "config-enums.h" */
GType
pika_canvas_padding_mode_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_CANVAS_PADDING_MODE_DEFAULT, "PIKA_CANVAS_PADDING_MODE_DEFAULT", "default" },
    { PIKA_CANVAS_PADDING_MODE_LIGHT_CHECK, "PIKA_CANVAS_PADDING_MODE_LIGHT_CHECK", "light-check" },
    { PIKA_CANVAS_PADDING_MODE_DARK_CHECK, "PIKA_CANVAS_PADDING_MODE_DARK_CHECK", "dark-check" },
    { PIKA_CANVAS_PADDING_MODE_CUSTOM, "PIKA_CANVAS_PADDING_MODE_CUSTOM", "custom" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_CANVAS_PADDING_MODE_DEFAULT, NC_("canvas-padding-mode", "From theme"), NULL },
    { PIKA_CANVAS_PADDING_MODE_LIGHT_CHECK, NC_("canvas-padding-mode", "Light check color"), NULL },
    { PIKA_CANVAS_PADDING_MODE_DARK_CHECK, NC_("canvas-padding-mode", "Dark check color"), NULL },
    { PIKA_CANVAS_PADDING_MODE_CUSTOM, NC_("canvas-padding-mode", "Custom color"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaCanvasPaddingMode", values);
      pika_type_set_translation_context (type, "canvas-padding-mode");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_cursor_format_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_CURSOR_FORMAT_BITMAP, "PIKA_CURSOR_FORMAT_BITMAP", "bitmap" },
    { PIKA_CURSOR_FORMAT_PIXBUF, "PIKA_CURSOR_FORMAT_PIXBUF", "pixbuf" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_CURSOR_FORMAT_BITMAP, NC_("cursor-format", "Black & white"), NULL },
    { PIKA_CURSOR_FORMAT_PIXBUF, NC_("cursor-format", "Fancy"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaCursorFormat", values);
      pika_type_set_translation_context (type, "cursor-format");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_cursor_mode_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_CURSOR_MODE_TOOL_ICON, "PIKA_CURSOR_MODE_TOOL_ICON", "tool-icon" },
    { PIKA_CURSOR_MODE_TOOL_CROSSHAIR, "PIKA_CURSOR_MODE_TOOL_CROSSHAIR", "tool-crosshair" },
    { PIKA_CURSOR_MODE_CROSSHAIR, "PIKA_CURSOR_MODE_CROSSHAIR", "crosshair" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_CURSOR_MODE_TOOL_ICON, NC_("cursor-mode", "Tool icon"), NULL },
    { PIKA_CURSOR_MODE_TOOL_CROSSHAIR, NC_("cursor-mode", "Tool icon with crosshair"), NULL },
    { PIKA_CURSOR_MODE_CROSSHAIR, NC_("cursor-mode", "Crosshair only"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaCursorMode", values);
      pika_type_set_translation_context (type, "cursor-mode");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_export_file_type_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_EXPORT_FILE_PNG, "PIKA_EXPORT_FILE_PNG", "png" },
    { PIKA_EXPORT_FILE_JPG, "PIKA_EXPORT_FILE_JPG", "jpg" },
    { PIKA_EXPORT_FILE_ORA, "PIKA_EXPORT_FILE_ORA", "ora" },
    { PIKA_EXPORT_FILE_PSD, "PIKA_EXPORT_FILE_PSD", "psd" },
    { PIKA_EXPORT_FILE_PDF, "PIKA_EXPORT_FILE_PDF", "pdf" },
    { PIKA_EXPORT_FILE_TIF, "PIKA_EXPORT_FILE_TIF", "tif" },
    { PIKA_EXPORT_FILE_BMP, "PIKA_EXPORT_FILE_BMP", "bmp" },
    { PIKA_EXPORT_FILE_WEBP, "PIKA_EXPORT_FILE_WEBP", "webp" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_EXPORT_FILE_PNG, NC_("export-file-type", "PNG Image"), NULL },
    { PIKA_EXPORT_FILE_JPG, NC_("export-file-type", "JPEG Image"), NULL },
    { PIKA_EXPORT_FILE_ORA, NC_("export-file-type", "OpenRaster Image"), NULL },
    { PIKA_EXPORT_FILE_PSD, NC_("export-file-type", "Photoshop Image"), NULL },
    { PIKA_EXPORT_FILE_PDF, NC_("export-file-type", "Portable Document Format"), NULL },
    { PIKA_EXPORT_FILE_TIF, NC_("export-file-type", "TIFF Image"), NULL },
    { PIKA_EXPORT_FILE_BMP, NC_("export-file-type", "Windows BMP Image"), NULL },
    { PIKA_EXPORT_FILE_WEBP, NC_("export-file-type", "WebP Image"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaExportFileType", values);
      pika_type_set_translation_context (type, "export-file-type");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_handedness_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_HANDEDNESS_LEFT, "PIKA_HANDEDNESS_LEFT", "left" },
    { PIKA_HANDEDNESS_RIGHT, "PIKA_HANDEDNESS_RIGHT", "right" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_HANDEDNESS_LEFT, NC_("handedness", "Left-handed"), NULL },
    { PIKA_HANDEDNESS_RIGHT, NC_("handedness", "Right-handed"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaHandedness", values);
      pika_type_set_translation_context (type, "handedness");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_help_browser_type_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_HELP_BROWSER_PIKA, "PIKA_HELP_BROWSER_PIKA", "pika" },
    { PIKA_HELP_BROWSER_WEB_BROWSER, "PIKA_HELP_BROWSER_WEB_BROWSER", "web-browser" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_HELP_BROWSER_PIKA, NC_("help-browser-type", "PIKA help browser"), NULL },
    { PIKA_HELP_BROWSER_WEB_BROWSER, NC_("help-browser-type", "Web browser"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaHelpBrowserType", values);
      pika_type_set_translation_context (type, "help-browser-type");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_icon_size_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_ICON_SIZE_SMALL, "PIKA_ICON_SIZE_SMALL", "small" },
    { PIKA_ICON_SIZE_MEDIUM, "PIKA_ICON_SIZE_MEDIUM", "medium" },
    { PIKA_ICON_SIZE_LARGE, "PIKA_ICON_SIZE_LARGE", "large" },
    { PIKA_ICON_SIZE_HUGE, "PIKA_ICON_SIZE_HUGE", "huge" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_ICON_SIZE_SMALL, NC_("icon-size", "Small size"), NULL },
    { PIKA_ICON_SIZE_MEDIUM, NC_("icon-size", "Medium size"), NULL },
    { PIKA_ICON_SIZE_LARGE, NC_("icon-size", "Large size"), NULL },
    { PIKA_ICON_SIZE_HUGE, NC_("icon-size", "Huge size"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaIconSize", values);
      pika_type_set_translation_context (type, "icon-size");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_position_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_POSITION_TOP, "PIKA_POSITION_TOP", "top" },
    { PIKA_POSITION_BOTTOM, "PIKA_POSITION_BOTTOM", "bottom" },
    { PIKA_POSITION_LEFT, "PIKA_POSITION_LEFT", "left" },
    { PIKA_POSITION_RIGHT, "PIKA_POSITION_RIGHT", "right" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_POSITION_TOP, NC_("position", "Top"), NULL },
    { PIKA_POSITION_BOTTOM, NC_("position", "Bottom"), NULL },
    { PIKA_POSITION_LEFT, NC_("position", "Left"), NULL },
    { PIKA_POSITION_RIGHT, NC_("position", "Right"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaPosition", values);
      pika_type_set_translation_context (type, "position");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_drag_zoom_mode_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PROP_DRAG_ZOOM_MODE_DISTANCE, "PROP_DRAG_ZOOM_MODE_DISTANCE", "distance" },
    { PROP_DRAG_ZOOM_MODE_DURATION, "PROP_DRAG_ZOOM_MODE_DURATION", "duration" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PROP_DRAG_ZOOM_MODE_DISTANCE, NC_("drag-zoom-mode", "By distance"), NULL },
    { PROP_DRAG_ZOOM_MODE_DURATION, NC_("drag-zoom-mode", "By duration"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaDragZoomMode", values);
      pika_type_set_translation_context (type, "drag-zoom-mode");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_space_bar_action_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_SPACE_BAR_ACTION_NONE, "PIKA_SPACE_BAR_ACTION_NONE", "none" },
    { PIKA_SPACE_BAR_ACTION_PAN, "PIKA_SPACE_BAR_ACTION_PAN", "pan" },
    { PIKA_SPACE_BAR_ACTION_MOVE, "PIKA_SPACE_BAR_ACTION_MOVE", "move" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_SPACE_BAR_ACTION_NONE, NC_("space-bar-action", "No action"), NULL },
    { PIKA_SPACE_BAR_ACTION_PAN, NC_("space-bar-action", "Pan view"), NULL },
    { PIKA_SPACE_BAR_ACTION_MOVE, NC_("space-bar-action", "Switch to Move tool"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaSpaceBarAction", values);
      pika_type_set_translation_context (type, "space-bar-action");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_window_hint_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_WINDOW_HINT_NORMAL, "PIKA_WINDOW_HINT_NORMAL", "normal" },
    { PIKA_WINDOW_HINT_UTILITY, "PIKA_WINDOW_HINT_UTILITY", "utility" },
    { PIKA_WINDOW_HINT_KEEP_ABOVE, "PIKA_WINDOW_HINT_KEEP_ABOVE", "keep-above" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_WINDOW_HINT_NORMAL, NC_("window-hint", "Normal window"), NULL },
    { PIKA_WINDOW_HINT_UTILITY, NC_("window-hint", "Utility window"), NULL },
    { PIKA_WINDOW_HINT_KEEP_ABOVE, NC_("window-hint", "Keep above"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaWindowHint", values);
      pika_type_set_translation_context (type, "window-hint");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}

GType
pika_zoom_quality_get_type (void)
{
  static const GEnumValue values[] =
  {
    { PIKA_ZOOM_QUALITY_LOW, "PIKA_ZOOM_QUALITY_LOW", "low" },
    { PIKA_ZOOM_QUALITY_HIGH, "PIKA_ZOOM_QUALITY_HIGH", "high" },
    { 0, NULL, NULL }
  };

  static const PikaEnumDesc descs[] =
  {
    { PIKA_ZOOM_QUALITY_LOW, NC_("zoom-quality", "Low"), NULL },
    { PIKA_ZOOM_QUALITY_HIGH, NC_("zoom-quality", "High"), NULL },
    { 0, NULL, NULL }
  };

  static GType type = 0;

  if (G_UNLIKELY (! type))
    {
      type = g_enum_register_static ("PikaZoomQuality", values);
      pika_type_set_translation_context (type, "zoom-quality");
      pika_enum_set_value_descriptions (type, descs);
    }

  return type;
}


/* Generated data ends here */

